@@ -27,7 +27,7 @@
  * list of people on the gedit Team.
  * See the ChangeLog files for a list of changes.
  *
- * $Id: gedit-commands-file.c,v 1.3 2006/01/03 17:19:10 paolo Exp $
+ * $Id: gedit-commands-file.c,v 1.6 2006/03/14 10:53:10 pborelli Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -104,39 +104,36 @@ load_file_list (GeditWindow         *window,
 		    (gedit_tab_get_state (tab) == GEDIT_TAB_STATE_NORMAL))
 		{
 			const gchar *uri;
-			gboolean     ret;
 
 			uri = (const gchar *)uris->data;
-			ret = _gedit_tab_load (tab,
-					       uri,
-					       encoding,
-					       line_pos,
-					       create);
+
+			_gedit_tab_load (tab,
+					 uri,
+					 encoding,
+					 line_pos,
+					 create);
 
 			uris = g_slist_next (uris);
 			jump_to = FALSE;
 
-			if (ret)
+			if (uris == NULL)
 			{
-				if (uris == NULL)
-				{
-					/* There is only a single file to load */
-					gchar *uri_for_display;
+				/* There is only a single file to load */
+				gchar *uri_for_display;
 
-					uri_for_display = gnome_vfs_format_uri_for_display (uri);
+				uri_for_display = gnome_vfs_format_uri_for_display (uri);
 
-					gedit_statusbar_flash_message (GEDIT_STATUSBAR (window->priv->statusbar),
-								       window->priv->generic_message_cid,
-								       _("Loading file '%s'\342\200\246"),
-								       uri_for_display);
+				gedit_statusbar_flash_message (GEDIT_STATUSBAR (window->priv->statusbar),
+							       window->priv->generic_message_cid,
+							       _("Loading file '%s'\342\200\246"),
+							       uri_for_display);
 
-					g_free (uri_for_display);
+				g_free (uri_for_display);
 
-					flash = FALSE;
-				}
-
-				++loaded_files;
+				flash = FALSE;
 			}
+
+			++loaded_files;
 		}
 	}
 
@@ -620,6 +617,8 @@ save_dialog_response_cb (GeditFileChooserDialog *dialog,
 					       _("Saving file '%s'\342\200\246"),
 					       uri_for_display);
 
+		g_free (uri_for_display);
+
 		_gedit_tab_save_as (tab, uri, encoding);
 	}
 
@@ -672,12 +671,17 @@ confirm_overwrite_callback (GtkFileChooser *dialog,
 			    gpointer        data)
 {
 	gchar *uri;
+	gboolean ro;
 
 	gedit_debug (DEBUG_COMMANDS);
 
 	uri = gtk_file_chooser_get_uri (dialog);
 
-	if (is_read_only (uri))
+	ro = is_read_only (uri);
+
+	g_free (uri);
+
+	if (ro)
 	{
 		if (replace_read_only_file (GTK_WINDOW (dialog), uri))
 			return GTK_FILE_CHOOSER_CONFIRMATION_ACCEPT_FILENAME;
@@ -1466,8 +1470,7 @@ close_confirmation_dialog_response_handler (GeditCloseConfirmationDialog *dlg,
 					    gint                          response_id,
 					    GeditWindow                  *window)
 {
-	const GList *unsaved_documents;
-	const GList *selected_documents;
+	GList *selected_documents;
 	gboolean is_closing_all;
 
 	gedit_debug (DEBUG_COMMANDS);
@@ -1477,8 +1480,6 @@ close_confirmation_dialog_response_handler (GeditCloseConfirmationDialog *dlg,
 
 	gtk_widget_hide (GTK_WIDGET (dlg));
 
-	unsaved_documents = gedit_close_confirmation_dialog_get_unsaved_documents (dlg);
-
 	switch (response_id)
 	{
 		case GTK_RESPONSE_YES: /* Save and Close */
@@ -1512,6 +1513,9 @@ close_confirmation_dialog_response_handler (GeditCloseConfirmationDialog *dlg,
 								 window);
 				}
 			}
+
+			g_list_free (selected_documents);
+
 			break;
 
 		case GTK_RESPONSE_NO: /* Close without Saving */
@@ -1527,6 +1531,9 @@ close_confirmation_dialog_response_handler (GeditCloseConfirmationDialog *dlg,
 			}
 			else
 			{
+				const GList *unsaved_documents;
+
+				unsaved_documents = gedit_close_confirmation_dialog_get_unsaved_documents (dlg);
 				g_return_if_fail (unsaved_documents->next == NULL);
 
 				close_document (window,
