@@ -29,7 +29,6 @@ import ElementTree as et
 
 class Manager:
 	GLADE_FILE = os.path.join(os.path.dirname(__file__), "tools.glade")
-	GCONF_DIR = '/apps/gedit-2/plugins/tools'
 
 	LABEL_COLUMN = 0 # For Combo and Tree
 	NODE_COLUMN  = 1 # For Tree only
@@ -70,12 +69,13 @@ class Manager:
 			Manager.__shared_state = self.__dict__
 		
 		callbacks = {
-			'on_new_tool_button_clicked'     : self.on_new_tool_button_clicked,
-			'on_remove_tool_button_clicked'  : self.on_remove_tool_button_clicked,
-			'on_tool_manager_dialog_response': self.on_tool_manager_dialog_response,
-			'on_accelerator_key_press'       : self.on_accelerator_key_press,
-			'on_accelerator_focus_in'        : self.on_accelerator_focus_in,
-			'on_accelerator_focus_out'       : self.on_accelerator_focus_out
+			'on_new_tool_button_clicked'      : self.on_new_tool_button_clicked,
+			'on_remove_tool_button_clicked'   : self.on_remove_tool_button_clicked,
+			'on_tool_manager_dialog_response' : self.on_tool_manager_dialog_response,
+			'on_tool_manager_dialog_focus_out': self.on_tool_manager_dialog_focus_out,
+			'on_accelerator_key_press'        : self.on_accelerator_key_press,
+			'on_accelerator_focus_in'         : self.on_accelerator_focus_in,
+			'on_accelerator_focus_out'        : self.on_accelerator_focus_out
 		}
 		
 		# Load the "main-window" widget from the glade file.
@@ -277,7 +277,7 @@ class Manager:
  			                           gtk.DIALOG_MODAL,
  			                           gtk.MESSAGE_ERROR,
  			                           gtk.BUTTONS_OK,
- 			                           _('This accelerator is already bound to %s') % self.current_node.get('label'))
+ 			                           _('This accelerator is already bound to %s') % tool.get('label'))
 			dialog.run()
 			dialog.destroy()
  			return False
@@ -307,7 +307,9 @@ class Manager:
 		elif event.keyval in range(gtk.keysyms.F1, gtk.keysyms.F12):
 			# New accelerator
 			self.set_accelerator(event.keyval, mask)
-			entry.set_text(self.current_node.get('accelerator'))
+			entry.set_text(
+			           default(self.current_node.get('accelerator'),
+			                   ''))
 			self['commands'].grab_focus()
 			# Capture all `normal characters`
 			return True			
@@ -315,7 +317,9 @@ class Manager:
 			if mask:
 				# New accelerator
 				self.set_accelerator(event.keyval, mask)
-				entry.set_text(self.current_node.get('accelerator'))
+				entry.set_text(
+				   default(self.current_node.get('accelerator'),
+				           ''))
 				self['commands'].grab_focus()
 			# Capture all `normal characters`
 			return True
@@ -347,5 +351,9 @@ class Manager:
 		self.tools.save()
 		update_tools_menu(tools = self.tools)
 		self.tools = None
+	
+	def on_tool_manager_dialog_focus_out(self, dialog, event):
+		self.save_current_tool()
+		update_tools_menu(tools = self.tools)
 
 # ex:noet:ts=8:
