@@ -139,7 +139,7 @@ class SnippetData:
 			return None
 	
 	def _override(self):
-		# Find the user file where this fella can find refugee
+		# Find the user file
 		target = SnippetsLibrary().get_user_library(self.language())
 
 		# Create a new node there with override
@@ -177,10 +177,11 @@ class SnippetData:
 	
 	def revert(self, snippet):
 		userlib = self.library()
+		self.set_library(snippet.library())
+		
 		userlib.remove(self.node)
 		
 		self.set_node(None)
-		self.set_library(snippet.library())
 
 		# Copy the properties
 		self.properties = snippet.properties
@@ -617,11 +618,12 @@ class SnippetsLibraryImpl:
 	def get_user_library(self, language):
 		target = None
 		
-		for library in self.libraries[language]:
-			if isinstance(library, SnippetsUserFile) and library.modifier:
-				target = library
-			elif not isinstance(library, SnippetsUserFile):
-				break
+		if language in self.libraries:
+			for library in self.libraries[language]:
+				if isinstance(library, SnippetsUserFile) and library.modifier:
+					target = library
+				elif not isinstance(library, SnippetsUserFile):
+					break
 		
 		if not target:
 			# Create a new user file then
@@ -656,8 +658,13 @@ class SnippetsLibraryImpl:
 		if not snippet.can_modify() or snippet.override:
 			return
 		
+		# Remove from the library
 		userlib = snippet.library()
 		userlib.remove(snippet.node)
+		
+		# Remove from the container
+		container = self.containers[userlib.language]
+		container.remove(snippet)
 	
 	def overrided(self, library, element):
 		id = NamespacedId(library.language, element.attrib.get('id')).id
